<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Event;
use Illuminate\Support\Facades\DB;

class EventController extends Controller
{
    public function index()
    {
        try {
            $entries = Event::with('user')->get();

            $data = $entries->map(function ($event) {
                return [
                    'E_Id'             => $event->E_Id,
                    'E_Name'           => $event->E_Name,
                    'E_Creater_Name'   => $event->E_Creater_Name,
                    'E_Creater_Mobile' => $event->E_Creater_Mobile,
                    'U_Id'             => $event->U_Id,
                    'Role_Id'          => $event->user->Role_Id ?? null,
                    'Mam_Id'           => $event->Mam_Id,
                    'E_StartDate'      => $event->E_StartDate,
                    'E_EndDate'        => $event->E_EndDate,
                    'E_StartTime'      => $event->E_StartTime,
                    'E_EndTime'        => $event->E_EndTime,
                    'E_Place'          => $event->E_Place,
                    'E_Description'    => $event->E_Description,
                    'E_State'          => $event->E_State,
                    'E_City'           => $event->E_City,
                    'E_Zipcode'        => $event->E_Zipcode,
                    'E_Address'        => $event->E_Address,
                    'E_Fees'           => $event->E_Fees,
                    'E_Status'         => $event->E_Status,
                    'E_Capacity'       => $event->E_Capacity,
                    'E_Booked_Count'   => $event->E_Booked_Count,
                    'deleted_at'       => $event->deleted_at,
                    'created_at'       => $event->created_at,
                    'updated_at'       => $event->updated_at,
                ];
            });

            return response()->json([
                'status' => 'success',
                'data'   => $data
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status'  => 'error',
                'message' => 'Something went wrong',
                'error'   => $e->getMessage()
            ], 500);
        }
    }

    // public function store(Request $request)
    // {
    //     try {
    //         // Validate request
    //         $validator = Validator::make($request->all(), [
    //             'E_Name'        => 'required|string',
    //             'E_Creater_Name' => 'required|string',
    //             'E_Creater_Mobile' => 'required|digits:10',
    //             'U_Id'          => 'required|exists:user_masters,U_Id',
    //             'E_StartDate'   => 'required|date|after_or_equal:today',
    //             'E_EndDate'     => 'required|date|after_or_equal:E_StartDate',
    //             'E_StartTime'   => 'required|date_format:H:i:s',
    //             'E_EndTime'     => 'required|date_format:H:i:s',
    //             'E_Place'       => 'required|string',
    //             'E_Description' => 'nullable|string',
    //             'E_State'       => 'required|string',
    //             'E_City'        => 'required|string',
    //             'E_Zipcode'     => 'nullable|max:20',
    //             'E_Address'     => 'required|string',
    //             'E_Fees'        => 'nullable|numeric',
    //             'E_Status'      => 'nullable|string|in:A,R,P,C,D',
    //             'E_Capacity'  => 'required|integer',
    //             'E_Booked_Count' => 'nullable|integer',
    //         ]);

    //         if ($validator->fails()) {
    //             return response()->json(['errors' => $validator->errors()], 422);
    //         }

    //         // ✅ Ensure E_EndTime is after E_StartTime when dates are the same
    //         if (
    //             $request->E_StartDate == $request->E_EndDate &&
    //             strtotime($request->E_EndTime) <= strtotime($request->E_StartTime)
    //         ) {
    //             return response()->json([
    //                 'errors' => ['E_EndTime' => ['End time must be after start time on the same date.']]
    //             ], 422);
    //         }

    //         // Default status 'P' if not provided
    //         $eventStatus = $request->input('E_Status') ?? 'P';

    //         // ✅ Create Event
    //         $event = Event::create([
    //             'E_Name'        => $request->E_Name,
    //             'E_Creater_Name' => $request->E_Creater_Name,
    //             'E_Creater_Mobile' => $request->E_Creater_Mobile,
    //             'U_Id'          => $request->U_Id,
    //             'E_StartDate'   => $request->E_StartDate,
    //             'E_EndDate'     => $request->E_EndDate,
    //             'E_StartTime'   => $request->E_StartTime,
    //             'E_EndTime'     => $request->E_EndTime,
    //             'E_Place'       => $request->E_Place,
    //             'E_Description' => $request->E_Description,
    //             'E_Fees'        => $request->E_Fees,
    //             'E_State'       => $request->E_State,
    //             'E_City'        => $request->E_City,
    //             'E_Zipcode'     => $request->E_Zipcode,
    //             'E_Address'     => $request->E_Address,
    //             'E_Status'      => $eventStatus,
    //             'E_Capacity' => $request->E_Capacity,
    //             'E_Booked_Count'  => $request->E_Booked_Count ?? 0,
    //         ]);

    //         // // ✅ Fetch Role_Id dynamically
    //         // $roleId = null;
    //         // if ($request->U_Id) {
    //         //     $user = DB::table('user_masters')->where('U_Id', $request->U_Id)->select('Role_Id')->first();
    //         //     $roleId = $user->Role_Id ?? null;
    //         // }

    //         // if (!$roleId && $request->Mam_Id) {
    //         //     $member = DB::table('committee_members')->where('Mam_Id', $request->Mam_Id)->first();
    //         //     if ($member) {
    //         //         $committeeUser = DB::table('user_master')->where('U_Id', $member->U_Id)->select('Role_Id')->first();
    //         //         $roleId = $committeeUser->Role_Id ?? null;
    //         //     }
    //         // }

    //         // ✅ Do NOT assign Role_Id to event directly
    //         return response()->json([
    //             'message' => 'Event created successfully',
    //             'event'   => $event,

    //         ], 201);
    //     } catch (\Exception $e) {
    //         return response()->json(['error' => $e->getMessage()], 500);
    //     }
    // }

    public function store(Request $request)
    {
        try {
            // ✅ Validate request
            $validator = Validator::make($request->all(), [
                'E_Name'            => 'required|string',
                'E_Creater_Name'    => 'required|string',
                'E_Creater_Mobile'  => 'required|digits:10',
                'U_Id'              => 'required|exists:user_masters,U_Id',
                'E_StartDate'       => 'required|date|after_or_equal:today',
                'E_EndDate'         => 'required|date|after_or_equal:E_StartDate',
                'E_StartTime'       => 'required|date_format:H:i:s',
                'E_EndTime'         => 'required|date_format:H:i:s',
                'E_Place'           => 'required|string',
                'E_Description'     => 'nullable|string',
                'E_State'           => 'required|string',
                'E_City'            => 'required|string',
                'E_Zipcode'         => 'nullable|max:20',
                'E_Address'         => 'required|string',
                'E_Fees'            => 'nullable|numeric',
                'E_Capacity'        => 'required|integer',
                'E_Booked_Count'    => 'nullable|integer',
            ]);

            if ($validator->fails()) {
                return response()->json(['errors' => $validator->errors()], 422);
            }

            // ✅ Ensure E_EndTime is after E_StartTime when dates are the same
            if (
                $request->E_StartDate == $request->E_EndDate &&
                strtotime($request->E_EndTime) <= strtotime($request->E_StartTime)
            ) {
                return response()->json([
                    'errors' => ['E_EndTime' => ['End time must be after start time on the same date.']]
                ], 422);
            }

            // ✅ Determine E_Status based on Role_Id
            $roleId = DB::table('user_masters')->where('U_Id', $request->U_Id)->value('Role_Id');

            if ($roleId == 2) {
                $eventStatus = 'A'; // Admin
            } elseif ($roleId == 3) {
                $eventStatus = 'P'; // Committee Member
            } else {
                $eventStatus = $request->input('E_Status') ?? 'P'; // Fallback
            }

            // ✅ Create Event
            $event = Event::create([
                'E_Name'            => $request->E_Name,
                'E_Creater_Name'    => $request->E_Creater_Name,
                'E_Creater_Mobile'  => $request->E_Creater_Mobile,
                'U_Id'              => $request->U_Id,
                'E_StartDate'       => $request->E_StartDate,
                'E_EndDate'         => $request->E_EndDate,
                'E_StartTime'       => $request->E_StartTime,
                'E_EndTime'         => $request->E_EndTime,
                'E_Place'           => $request->E_Place,
                'E_Description'     => $request->E_Description,
                'E_State'           => $request->E_State,
                'E_City'            => $request->E_City,
                'E_Zipcode'         => $request->E_Zipcode,
                'E_Address'         => $request->E_Address,
                'E_Fees'            => $request->E_Fees,
                'E_Status'          => $eventStatus,
                'E_Capacity'        => $request->E_Capacity,
                'E_Booked_Count'    => $request->E_Booked_Count ?? 0,
            ]);

            return response()->json([
                'message' => 'Event created successfully',
                'event'   => $event,
                'Role_Id'  => $roleId,
            ], 201);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    // public function store(Request $request)
    // {
    //     try {
    //         // ✅ Validate request
    //         $validator = Validator::make($request->all(), [
    //             'E_Name'            => 'required|string',
    //             'E_Creater_Name'    => 'required|string',
    //             'E_Creater_Mobile'  => 'required|digits:10',
    //             'U_Id'              => 'required|exists:user_masters,U_Id',
    //             'E_StartDate'       => 'required|date|after_or_equal:today',
    //             'E_EndDate'         => 'required|date|after_or_equal:E_StartDate',
    //             'E_StartTime'       => 'required|date_format:H:i:s',
    //             'E_EndTime'         => 'required|date_format:H:i:s',
    //             'E_Place'           => 'required|string',
    //             'E_Description'     => 'nullable|string',
    //             'E_State'           => 'required|string',
    //             'E_City'            => 'required|string',
    //             'E_Zipcode'         => 'nullable|max:20',
    //             'E_Address'         => 'required|string',
    //             'E_Fees'            => 'nullable|numeric',
    //             'E_Capacity'        => 'required|integer',
    //             'E_Booked_Count'    => 'nullable|integer',
    //         ]);

    //         if ($validator->fails()) {
    //             return response()->json(['errors' => $validator->errors()], 422);
    //         }

    //         // ✅ Ensure E_EndTime is after E_StartTime when dates are the same
    //         if (
    //             $request->E_StartDate == $request->E_EndDate &&
    //             strtotime($request->E_EndTime) <= strtotime($request->E_StartTime)
    //         ) {
    //             return response()->json([
    //                 'errors' => ['E_EndTime' => ['End time must be after start time on the same date.']]
    //             ], 422);
    //         }

    //         // ✅ Get Role_Id from user_masters
    //         $roleId = DB::table('user_masters')->where('U_Id', $request->U_Id)->value('Role_Id');

    //         // ✅ Determine E_Status based on Role_Id
    //         if ($roleId == 2) {
    //             $eventStatus = 'A'; // Admin
    //         } elseif ($roleId == 3) {
    //             $eventStatus = 'P'; // Committee Member
    //         } else {
    //             $eventStatus = $request->input('E_Status') ?? 'P'; // Default
    //         }

    //         // ✅ Create the event
    //         $event = Event::create([
    //             'E_Name'            => $request->E_Name,
    //             'E_Creater_Name'    => $request->E_Creater_Name,
    //             'E_Creater_Mobile'  => $request->E_Creater_Mobile,
    //             'U_Id'              => $request->U_Id,
    //             'E_StartDate'       => $request->E_StartDate,
    //             'E_EndDate'         => $request->E_EndDate,
    //             'E_StartTime'       => $request->E_StartTime,
    //             'E_EndTime'         => $request->E_EndTime,
    //             'E_Place'           => $request->E_Place,
    //             'E_Description'     => $request->E_Description,
    //             'E_State'           => $request->E_State,
    //             'E_City'            => $request->E_City,
    //             'E_Zipcode'         => $request->E_Zipcode,
    //             'E_Address'         => $request->E_Address,
    //             'E_Fees'            => $request->E_Fees,
    //             'E_Status'          => $eventStatus,
    //             'E_Capacity'        => $request->E_Capacity,
    //             'E_Booked_Count'    => $request->E_Booked_Count ?? 0,
    //         ]);

    //         // ✅ Format response with nested U_Id + Role_Id
    //         $responseData = $event->toArray();
    //         $responseData['U_Id'] = [
    //             'U_Id'     => $event->U_Id,
    //             'Role_Id'  => $roleId
    //         ];

    //         return response()->json([
    //             'message' => 'Event created successfully',
    //             'event'   => $responseData
    //         ], 201);
    //     } catch (\Exception $e) {
    //         return response()->json(['error' => $e->getMessage()], 500);
    //     }
    // }

    public function show($id)
    {
        try {
            $entry = Event::with('user')->find($id);

            if (!$entry) {
                return response()->json([
                    'status' => 'error',
                    'message' => 'Event not found.'
                ], 404);
            }

            $data = [
                'E_Id'             => $entry->E_Id,
                'E_Name'           => $entry->E_Name,
                'E_Creater_Name'   => $entry->E_Creater_Name,
                'E_Creater_Mobile' => $entry->E_Creater_Mobile,
                'U_Id'             => $entry->U_Id,
                'Role_Id'          => $entry->user->Role_Id ?? null,
                'Mam_Id'           => $entry->Mam_Id,
                'E_StartDate'      => $entry->E_StartDate,
                'E_EndDate'        => $entry->E_EndDate,
                'E_StartTime'      => $entry->E_StartTime,
                'E_EndTime'        => $entry->E_EndTime,
                'E_Place'          => $entry->E_Place,
                'E_Description'    => $entry->E_Description,
                'E_State'          => $entry->E_State,
                'E_City'           => $entry->E_City,
                'E_Zipcode'        => $entry->E_Zipcode,
                'E_Address'        => $entry->E_Address,
                'E_Fees'           => $entry->E_Fees,
                'E_Status'         => $entry->E_Status,
                'E_Capacity'       => $entry->E_Capacity,
                'E_Booked_Count'   => $entry->E_Booked_Count,
                'deleted_at'       => $entry->deleted_at,
                'created_at'       => $entry->created_at,
                'updated_at'       => $entry->updated_at,
            ];

            return response()->json([
                'status' => 'success',
                'data'   => $data
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status'  => 'error',
                'message' => 'Something went wrong',
                'error'   => $e->getMessage()
            ], 500);
        }
    }

    // public function update(Request $request, $id)
    // {
    //     try {
    //         // Find the event
    //         $event = Event::find($id);
    //         if (!$event) {
    //             return response()->json(['error' => 'Event not found'], 404);
    //         }

    //         // Validate request (only validate fields that are present)
    //         $validator = Validator::make($request->all(), [
    //             'E_Name'        => 'sometimes|required|string',
    //             'E_Creater_Name' => 'sometimes|required|string',
    //             'E_Creater_Mobile' => 'sometimes|required|digits:10',
    //             'U_Id'          => 'sometimes|required|exists:user_masters,U_Id',
    //             'E_StartDate'   => 'sometimes|required|date|after_or_equal:today',
    //             'E_EndDate'     => 'sometimes|required|date|after_or_equal:E_StartDate',
    //             'E_StartTime'   => 'sometimes|required|date_format:H:i:s',
    //             'E_EndTime'     => 'sometimes|required|date_format:H:i:s',
    //             'E_Place'       => 'sometimes|required|string',
    //             'E_Description' => 'nullable|string',
    //             'E_State'       => 'sometimes|required|string',
    //             'E_City'        => 'sometimes|required|string',
    //             'E_Zipcode'     => 'nullable|max:20',
    //             'E_Address'     => 'sometimes|required|string',
    //             'E_Fees'        => 'nullable|numeric',
    //             'E_Status'      => 'nullable|string|in:A,R,P,C,D',
    //             'E_Capacity'    => 'sometimes|required|integer',
    //             'E_Booked_Count' => 'nullable|integer',
    //         ]);

    //         if ($validator->fails()) {
    //             return response()->json(['errors' => $validator->errors()], 422);
    //         }

    //         // Check for time logic on same-day events
    //         if (
    //             $request->has('E_StartDate') && $request->has('E_EndDate') &&
    //             $request->E_StartDate == $request->E_EndDate &&
    //             $request->has('E_StartTime') && $request->has('E_EndTime') &&
    //             strtotime($request->E_EndTime) <= strtotime($request->E_StartTime)
    //         ) {
    //             return response()->json([
    //                 'errors' => ['E_EndTime' => ['End time must be after start time on the same date.']]
    //             ], 422);
    //         }

    //         // Prepare data to update (only include fields present in the request)
    //         $updateData = [];

    //         // List of fields that can be updated
    //         $fillableFields = [
    //             'E_Name',
    //             'E_Creater_Name',
    //             'E_Creater_Mobile',
    //             'U_Id',
    //             'E_StartDate',
    //             'E_EndDate',
    //             'E_StartTime',
    //             'E_EndTime',
    //             'E_Place',
    //             'E_Description',
    //             'E_State',
    //             'E_City',
    //             'E_Zipcode',
    //             'E_Address',
    //             'E_Fees',
    //             'E_Status',
    //             'E_Capacity',
    //             'E_Booked_Count'
    //         ];

    //         // Only add fields that are present in the request
    //         foreach ($fillableFields as $field) {
    //             if ($request->has($field)) {
    //                 $updateData[$field] = $request->input($field);
    //             }
    //         }

    //         // Update event with only provided fields
    //         $event->update($updateData);

    //         // Fetch Role_Id dynamically
    //         $roleId = null;
    //         if ($request->has('U_Id') && $request->U_Id) {
    //             $user = DB::table('user_masters')->where('U_Id', $request->U_Id)->select('Role_Id')->first();
    //             $roleId = $user->Role_Id ?? null;
    //         }

    //         return response()->json([
    //             'message' => 'Event updated successfully',
    //             'event'   => $event->fresh(), // Fetch updated event
    //             'role'    => $roleId,
    //         ], 200);
    //     } catch (\Exception $e) {
    //         return response()->json(['error' => $e->getMessage()], 500);
    //     }
    // }
    // public function update(Request $request, $id)
    // {
    //     try {
    //         $event = Event::findOrFail($id);

    //         // Validate fields
    //         $validator = Validator::make($request->all(), [
    //             'E_Name'        => 'sometimes|string|max:255',
    //             'E_Creater_Name' => 'sometimes|string',
    //             'E_Creater_Mobile' => 'sometimes|digits:10',
    //             'E_StartDate'   => 'sometimes|date',
    //             'E_EndDate'     => 'sometimes|date|after_or_equal:E_StartDate',
    //             'E_StartTime'   => 'sometimes|date_format:H:i:s',
    //             'E_EndTime'     => 'sometimes|date_format:H:i:s',
    //             'E_Place'       => 'sometimes|string|max:255',
    //             'E_Description' => 'sometimes|string|nullable',
    //             'E_Fees'        => 'sometimes|numeric|nullable',
    //             'E_State'       => 'sometimes|string|max:255',
    //             'E_City'        => 'sometimes|string|max:255',
    //             'E_Zipcode'     => 'sometimes|max:20|nullable',
    //             'E_Address'     => 'sometimes|string',
    //             'E_Status'      => 'sometimes|string|in:A,R,P,C,D',
    //             'No_Of_People'  => 'sometimes|integer',
    //         ]);

    //         if ($validator->fails()) {
    //             return response()->json(['errors' => $validator->errors()], 422);
    //         }

    //         // Dates and time logic
    //         $startDate = $request->input('E_StartDate', $event->E_StartDate);
    //         $endDate = $request->input('E_EndDate', $event->E_EndDate);
    //         $startTime = $request->input('E_StartTime', $event->E_StartTime);
    //         $endTime = $request->input('E_EndTime', $event->E_EndTime);

    //         if ($startDate == $endDate && strtotime($endTime) <= strtotime($startTime)) {
    //             return response()->json([
    //                 'errors' => ['E_EndTime' => ['End time must be after start time on the same date.']]
    //             ], 422);
    //         }

    //         $newStatus = $request->input('E_Status', $event->E_Status);

    //         // Block updates if event is Rejected or Cancelled
    //         if (in_array($event->E_Status, ['R', 'C'])) {
    //             return response()->json(['error' => 'Rejected or Cancelled events cannot be updated.'], 403);
    //         }

    //         // If current status is Pending
    //         if ($event->E_Status === 'P' && $request->has('E_Status')) {
    //             if (!in_array($newStatus, ['A', 'R'])) {
    //                 return response()->json(['error' => 'Pending events can only be Approved or Rejected.'], 403);
    //             }
    //         }

    //         // If current status is Approved
    //         if ($event->E_Status === 'A' && $request->has('E_Status')) {
    //             if (!in_array($newStatus, ['C', 'D'])) {
    //                 return response()->json(['error' => 'Approved events can only be Cancelled or marked as Done.'], 403);
    //             }
    //         }

    //         // ✅ Update event
    //         $event->update($request->all());

    //         return response()->json([
    //             'message' => 'Event updated successfully',
    //             'event'   => $event,
    //         ], 200);
    //     } catch (\Exception $e) {
    //         return response()->json(['error' => $e->getMessage()], 500);
    //     }
    // }

    public function update(Request $request, $id)
    {
        try {
            $event = Event::findOrFail($id);

            // Validate fields
            $validator = Validator::make($request->all(), [
                'E_Name'            => 'sometimes|string|max:255',
                'E_Creater_Name'    => 'sometimes|string',
                'E_Creater_Mobile'  => 'sometimes|digits:10',
                'E_StartDate'       => 'sometimes|date',
                'E_EndDate'         => 'sometimes|date|after_or_equal:E_StartDate',
                'E_StartTime'       => 'sometimes|date_format:H:i:s',
                'E_EndTime'         => 'sometimes|date_format:H:i:s',
                'E_Place'           => 'sometimes|string|max:255',
                'E_Description'     => 'sometimes|string|nullable',
                'E_Fees'            => 'sometimes|numeric|nullable',
                'E_State'           => 'sometimes|string|max:255',
                'E_City'            => 'sometimes|string|max:255',
                'E_Zipcode'         => 'sometimes|max:20|nullable',
                'E_Address'         => 'sometimes|string',
                'E_Status'          => 'sometimes|string|in:A,R,P,C,D',
                'No_Of_People'      => 'sometimes|integer',
                'U_Id'              => 'sometimes|integer|exists:user_masters,U_Id',
            ]);

            if ($validator->fails()) {
                return response()->json(['errors' => $validator->errors()], 422);
            }

            // Handle start/end date and time logic
            $startDate = $request->input('E_StartDate', $event->E_StartDate);
            $endDate = $request->input('E_EndDate', $event->E_EndDate);
            $startTime = $request->input('E_StartTime', $event->E_StartTime);
            $endTime = $request->input('E_EndTime', $event->E_EndTime);

            if ($startDate == $endDate && strtotime($endTime) <= strtotime($startTime)) {
                return response()->json([
                    'errors' => ['E_EndTime' => ['End time must be after start time on the same date.']]
                ], 422);
            }

            // Set status based on role if not provided
            if (!$request->has('E_Status') && $request->has('U_Id')) {
                $roleId = DB::table('user_masters')->where('U_Id', $request->U_Id)->value('Role_Id');
                if ($roleId == 2) {
                    $request->merge(['E_Status' => 'A']);
                } elseif ($roleId == 3) {
                    $request->merge(['E_Status' => 'P']);
                }
            }

            $newStatus = $request->input('E_Status', $event->E_Status);

            // Block updates if event is Rejected or Cancelled
            if (in_array($event->E_Status, ['R', 'C'])) {
                return response()->json(['error' => 'Rejected or Cancelled events cannot be updated.'], 403);
            }

            // If current status is Pending
            if ($event->E_Status === 'P' && $request->has('E_Status')) {
                if (!in_array($newStatus, ['A', 'R'])) {
                    return response()->json(['error' => 'Pending events can only be Approved or Rejected.'], 403);
                }
            }

            // If current status is Approved
            if ($event->E_Status === 'A' && $request->has('E_Status')) {
                if (!in_array($newStatus, ['C', 'D'])) {
                    return response()->json(['error' => 'Approved events can only be Cancelled or marked as Done.'], 403);
                }
            }

            // ✅ Update event with only allowed fields
            $event->update($request->only([
                'E_Name',
                'E_Creater_Name',
                'E_Creater_Mobile',
                'E_StartDate',
                'E_EndDate',
                'E_StartTime',
                'E_EndTime',
                'E_Place',
                'E_Description',
                'E_Fees',
                'E_State',
                'E_City',
                'E_Zipcode',
                'E_Address',
                'E_Status',
                'No_Of_People',
                'U_Id',
            ]));

            return response()->json([
                'message' => 'Event updated successfully',
                'event'   => $event,
            ], 200);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function destroy($id)
    {
        try {
            // Find the event (only non-deleted events)
            $event = Event::find($id);
            if (!$event) {
                return response()->json(['error' => 'Event not found or already deleted'], 404);
            }

            // Perform soft delete
            $event->delete();

            return response()->json(['message' => 'Event soft deleted successfully'], 200);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function deleted()
    {
        try {
            $trashedItems = Event::onlyTrashed()->get();

            return response()->json([
                'message' => 'Soft deleted marketplace items fetched successfully',
                'data' => $trashedItems
            ], 200);
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }
}
