<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        // Create package_masters table without D_Id and Dis_Merge columns
        Schema::create('package_masters', function (Blueprint $table) {
            $table->bigIncrements('PackageId');
            $table->string('PackageName');
            $table->longText('Description')->nullable();
            $table->enum('Status', ['A', 'D'])->default('A');
            $table->integer('MaxUsers')->default(0);
            $table->integer('Duration_Value');
            $table->unsignedBigInteger('DT_Id');
            $table->foreign('DT_Id')->references('DT_Id')->on('duration_types')->onDelete('cascade');
            $table->integer('Dis_Merge')->default(1);
            $table->unsignedBigInteger('PVT_Id');
            $table->foreign('PVT_Id')->references('PVT_Id')->on('price_type_values')->onDelete('cascade');
            $table->decimal('Final_Price', 10, 2);
            $table->integer('Total_Duration')->nullable();
            $table->timestamps();
        });

        // Create the package_discount pivot table for the many-to-many relationship with discounts
        Schema::create('package_discount', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('PackageId');
            $table->unsignedBigInteger('D_Id');
            $table->foreign('PackageId')->references('PackageId')->on('package_masters')->onDelete('cascade');
            $table->foreign('D_Id')->references('D_Id')->on('discount_masters')->onDelete('cascade');
            $table->timestamps();
        });

        // Create package_feature_pivot table for many-to-many relationship with package_features
        Schema::create('package_feature_pivot', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('PackageId');
            $table->unsignedBigInteger('Package_Fea_Id');
            $table->foreign('PackageId')->references('PackageId')->on('package_masters')->onDelete('cascade');
            $table->foreign('Package_Fea_Id')->references('Package_Fea_Id')->on('package_features')->onDelete('cascade');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        // Drop the pivot table and main tables
        Schema::dropIfExists('package_discount');
        Schema::dropIfExists('package_feature_pivot');
        Schema::dropIfExists('package_masters');
    }
};
